Package: VariantTools
Type: Package
Title: Tools for Exploratory Analysis of Variant Calls
Version: 1.55.0
Author: Michael Lawrence, Jeremiah Degenhardt, Robert Gentleman
Maintainer: Michael Lawrence <lawremi@gmail.com>
Description: Explore, diagnose, and compare variant calls using filters.
Depends: R (>= 3.5.0), S4Vectors (>= 0.17.33), IRanges (>= 2.13.12),
        GenomicRanges (>= 1.31.8), VariantAnnotation (>= 1.11.16),
        methods
Imports: Rsamtools (>= 1.31.2), BiocGenerics, Biostrings, parallel,
        GenomicFeatures (>= 1.31.3), Matrix, rtracklayer (>= 1.39.7),
        BiocParallel, GenomeInfoDb, BSgenome, Biobase
Suggests: RUnit, LungCancerLines (>= 0.0.6), RBGL, graph, gmapR (>=
        1.21.3), TxDb.Hsapiens.UCSC.hg19.knownGene, org.Hs.eg.db
License: Artistic-2.0
LazyLoad: yes
biocViews: Genetics, GeneticVariability, Sequencing
git_url: https://git.bioconductor.org/packages/VariantTools
git_branch: devel
git_last_commit: 48b610f
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-05-18
NeedsCompilation: no
Packaged: 2026-05-18 23:46:49 UTC; biocbuild
Built: R 4.6.0; ; 2026-05-19 05:13:24 UTC; unix
