import(methods)
import(BiocGenerics)
import(S4Vectors)
import(IRanges)
import(GenomicRanges)
import(VariantAnnotation)
import(GenomeInfoDb)
importFrom(stats, dbinom, dhyper, pbinom, pt, setNames)
importFrom(utils, packageDescription)
importFrom(parallel, mclapply, mcmapply)
importFrom(Biostrings, DNAStringSet, detail, DNA_BASES)
importFrom(Rsamtools, BamFile, ScanBamParam, bamWhich, ApplyPileupsParam,
           PileupFiles, plpWhat, "plpWhat<-", applyPileups)
importFrom(GenomicFeatures, cdsBy, exonsBy, transcriptLocs2refLocs)
importClassesFrom(Matrix, dgTMatrix)
importFrom(rtracklayer, import)
importClassesFrom(rtracklayer, BigWigFile)
importFrom(tools, file_ext)
importFrom(BiocParallel, bpvec, registered, bplapply, bpmapply, bpnworkers)
importFrom(BSgenome, getSeq)
importFrom(Biobase, sampleNames, "sampleNames<-")

export(callVariants, qaVariants, tallyVariants, postFilterVariants)
export(MinTotalDepthFilter)

export(calculateConcordanceMatrix,
       callVariantConcordance, calculateVariantConcordance)
export(VariantQAFilters, VariantCallingFilters,
       VariantPostFilters, TallyVariantsParam)
export(variantGR2Vcf)

export(callSampleSpecificVariants, SampleSpecificVariantFilters,
       annotateWithControlDepth)

export(SetdiffVariantsFilter, DepthFETFilter, MaxControlFreqFilter)

export(callWildtype, minCallableCoverage)

## some utilities
export(matchVariants, "%variant_in%", extractCoverageForPositions)
export(pileupVariants)

export(CallGenotypesParam)
exportMethods(callGenotypes)
