\name{detectQualityType}
\alias{detectQualityType}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
%%  ~~function to do ... ~~
A function to detect the quality score (Qscore) type contained in a BAM
file. This function is needed as gSNAP will produce non-standard bam
files 
}
\description{
  A function to detect the quality score (Qscore) type contained in a
  BAM file. This function is needed as gSNAP will produce non-standard
  bam files
}
\usage{
detectQualityType(bamfile, nrows = 5000)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{bamfile}{
%%     ~~Describe \code{bamfile} here~~
}
  \item{nrows}{
%%     ~~Describe \code{nrows} here~~
}
}
\author{
%%  ~~who you are~~
Jeremiah Degenhardt
}

\keyword{internal}
