\name{annotateTrans}
\alias{annotateTrans}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
  %%  ~~function to do ... ~~
  A function to annotate a transcript grl with variant information. 
}
\description{
  %%  ~~ A concise (1-5 lines) description of what the function does. ~~
  Given a txbd, coverage RLE and set of functional variants, this function
  will return a GRangesList of transcripts annotated with additional
  metadata which includes the fraction of the transcript that is callable
  defined by the function isCallable and the number of functional variants
  that fall in the transcript.
}
\usage{
annotateTrans(txdb, cov, anno_gr)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
\item{txdb}{
  %%     ~~Describe \code{txdb} here~~
  a txdb object
}
\item{cov}{
  %%     ~~Describe \code{cov} here~~
  A coverage RLE as generated by the getCov function
}
\item{anno_gr}{
  %%     ~~Describe \code{anno_gr} here~~
  a GRanges object with variants annotaed for transcript occurance and
  consequence. The transcipt IDs are assumed to be ref_seq IDs. 
}
\item{cores}{
  %%     ~~Describe \code{cores} here~~
  Number of cores to be used in the parallel aspects of the
  code. Setting cores to 1 will run on a single core.
}
}
\value{
%%  ~Describe the value returned
%%  If it is a LIST, use
%%  \item{comp1 }{Description of 'comp1'}
%%  \item{comp2 }{Description of 'comp2'}
%% ...
Returns a GRangesList of the transcripts with metadata columns
added for the fraction of the cds or exon region that is considered
callable and the number of protein altering mutations found in the total
cds regions.
}
\author{
%%  ~~who you are~~
Jeremiah Degenhardt
}

\keyword{internal}
