\name{VEP2gr}
\alias{VEP2gr}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
%%  ~~function to do ... ~~
Convert a Variant Effect Predictor tab separated file to a GRanges
object. 
}
\description{
%%  ~~ A concise (1-5 lines) description of what the function does. ~~
This simple function will convert a data.frame generated from
reading in the results of running Variant Effect Predictor into
a GRanges object with some of the associated information attached as
ElementMetaData columns 
}
\usage{
VEP2gr(VEP_tab)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{VEP_tab}{
%%     ~~Describe \code{VEP_tab} here~~
A data,frame object with appropriate column names generated by reading
in the output from Variant Effect Predictor
}
}
\value{
%%  ~Describe the value returned
%%  If it is a LIST, use
%%  \item{comp1 }{Description of 'comp1'}
%%  \item{comp2 }{Description of 'comp2'}
%% ...
A GRanges object for each variant listed in the output of Variant Effect
Predictor. The Granges will have additional ElementMetaData columns
Allele (the variant allele), Gene (the gene ID given by VEP), TXID
(transcript ID filled in from the 'Feature' column in VEP),
Feature_type, Consequence and Existing_variation (giving rsID or cosmic
ID if they exist).
}

\author{
%%  ~~who you are~~
Jeremiah Degenhardt
}

\keyword{internal}
